==> open-cluster-management-operator-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/ExternalDNSConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExternalDNSConfigFluentImpl<A extends ExternalDNSConfigFluent<A>> extends BaseFluent<A> implements ExternalDNSConfigFluent<A>{
  public ExternalDNSConfigFluentImpl() {
  }
  public ExternalDNSConfigFluentImpl(ExternalDNSConfig instance) {
    this.withAws(instance.getAws()); 
    this.withGcp(instance.getGcp()); 
  }
  private ExternalDNSAWSConfigBuilder aws;
  private ExternalDNSGCPConfigBuilder gcp;
  
  /**
   * This method has been deprecated, please use method buildAws instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalDNSAWSConfig getAws() {
    return this.aws!=null ?this.aws.build():null;
  }
  public ExternalDNSAWSConfig buildAws() {
    return this.aws!=null ?this.aws.build():null;
  }
  public A withAws(ExternalDNSAWSConfig aws) {
    _visitables.get("aws").remove(this.aws);
    if (aws!=null){ this.aws= new ExternalDNSAWSConfigBuilder(aws); _visitables.get("aws").add(this.aws);} else { this.aws = null; _visitables.get("aws").remove(this.aws); } return (A) this;
  }
  public Boolean hasAws() {
    return this.aws != null;
  }
  public ExternalDNSConfigFluent.AwsNested<A> withNewAws() {
    return new ExternalDNSConfigFluentImpl.AwsNestedImpl();
  }
  public ExternalDNSConfigFluent.AwsNested<A> withNewAwsLike(ExternalDNSAWSConfig item) {
    return new ExternalDNSConfigFluentImpl.AwsNestedImpl(item);
  }
  public ExternalDNSConfigFluent.AwsNested<A> editAws() {
    return withNewAwsLike(getAws());
  }
  public ExternalDNSConfigFluent.AwsNested<A> editOrNewAws() {
    return withNewAwsLike(getAws() != null ? getAws(): new ExternalDNSAWSConfigBuilder().build());
  }
  public ExternalDNSConfigFluent.AwsNested<A> editOrNewAwsLike(ExternalDNSAWSConfig item) {
    return withNewAwsLike(getAws() != null ? getAws(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalDNSGCPConfig getGcp() {
    return this.gcp!=null ?this.gcp.build():null;
  }
  public ExternalDNSGCPConfig buildGcp() {
    return this.gcp!=null ?this.gcp.build():null;
  }
  public A withGcp(ExternalDNSGCPConfig gcp) {
    _visitables.get("gcp").remove(this.gcp);
    if (gcp!=null){ this.gcp= new ExternalDNSGCPConfigBuilder(gcp); _visitables.get("gcp").add(this.gcp);} else { this.gcp = null; _visitables.get("gcp").remove(this.gcp); } return (A) this;
  }
  public Boolean hasGcp() {
    return this.gcp != null;
  }
  public ExternalDNSConfigFluent.GcpNested<A> withNewGcp() {
    return new ExternalDNSConfigFluentImpl.GcpNestedImpl();
  }
  public ExternalDNSConfigFluent.GcpNested<A> withNewGcpLike(ExternalDNSGCPConfig item) {
    return new ExternalDNSConfigFluentImpl.GcpNestedImpl(item);
  }
  public ExternalDNSConfigFluent.GcpNested<A> editGcp() {
    return withNewGcpLike(getGcp());
  }
  public ExternalDNSConfigFluent.GcpNested<A> editOrNewGcp() {
    return withNewGcpLike(getGcp() != null ? getGcp(): new ExternalDNSGCPConfigBuilder().build());
  }
  public ExternalDNSConfigFluent.GcpNested<A> editOrNewGcpLike(ExternalDNSGCPConfig item) {
    return withNewGcpLike(getGcp() != null ? getGcp(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExternalDNSConfigFluentImpl that = (ExternalDNSConfigFluentImpl) o;
    if (aws != null ? !aws.equals(that.aws) :that.aws != null) return false;
    if (gcp != null ? !gcp.equals(that.gcp) :that.gcp != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(aws,  gcp,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (aws != null) { sb.append("aws:"); sb.append(aws + ","); }
    if (gcp != null) { sb.append("gcp:"); sb.append(gcp); }
    sb.append("}");
    return sb.toString();
  }
  class AwsNestedImpl<N> extends ExternalDNSAWSConfigFluentImpl<ExternalDNSConfigFluent.AwsNested<N>> implements ExternalDNSConfigFluent.AwsNested<N>,Nested<N>{
    AwsNestedImpl(ExternalDNSAWSConfig item) {
      this.builder = new ExternalDNSAWSConfigBuilder(this, item);
    }
    AwsNestedImpl() {
      this.builder = new ExternalDNSAWSConfigBuilder(this);
    }
    ExternalDNSAWSConfigBuilder builder;
    public N and() {
      return (N) ExternalDNSConfigFluentImpl.this.withAws(builder.build());
    }
    public N endAws() {
      return and();
    }
    
  }
  class GcpNestedImpl<N> extends ExternalDNSGCPConfigFluentImpl<ExternalDNSConfigFluent.GcpNested<N>> implements ExternalDNSConfigFluent.GcpNested<N>,Nested<N>{
    GcpNestedImpl(ExternalDNSGCPConfig item) {
      this.builder = new ExternalDNSGCPConfigBuilder(this, item);
    }
    GcpNestedImpl() {
      this.builder = new ExternalDNSGCPConfigBuilder(this);
    }
    ExternalDNSGCPConfigBuilder builder;
    public N and() {
      return (N) ExternalDNSConfigFluentImpl.this.withGcp(builder.build());
    }
    public N endGcp() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/ExternalDNSConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExternalDNSConfigFluentImpl<A extends ExternalDNSConfigFluent<A>> extends BaseFluent<A> implements ExternalDNSConfigFluent<A>{
  public ExternalDNSConfigFluentImpl() {
  }
  public ExternalDNSConfigFluentImpl(ExternalDNSConfig instance) {
    if (instance != null) {
      this.withAws(instance.getAws());
      this.withGcp(instance.getGcp());
    }
  }
  private ExternalDNSAWSConfigBuilder aws;
  private ExternalDNSGCPConfigBuilder gcp;
  
  /**
   * This method has been deprecated, please use method buildAws instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalDNSAWSConfig getAws() {
    return this.aws!=null ?this.aws.build():null;
  }
  public ExternalDNSAWSConfig buildAws() {
    return this.aws!=null ?this.aws.build():null;
  }
  public A withAws(ExternalDNSAWSConfig aws) {
    _visitables.get("aws").remove(this.aws);
    if (aws!=null){ this.aws= new ExternalDNSAWSConfigBuilder(aws); _visitables.get("aws").add(this.aws);} else { this.aws = null; _visitables.get("aws").remove(this.aws); } return (A) this;
  }
  public Boolean hasAws() {
    return this.aws != null;
  }
  public ExternalDNSConfigFluentImpl.AwsNested<A> withNewAws() {
    return new ExternalDNSConfigFluentImpl.AwsNestedImpl();
  }
  public ExternalDNSConfigFluentImpl.AwsNested<A> withNewAwsLike(ExternalDNSAWSConfig item) {
    return new ExternalDNSConfigFluentImpl.AwsNestedImpl(item);
  }
  public ExternalDNSConfigFluentImpl.AwsNested<A> editAws() {
    return withNewAwsLike(getAws());
  }
  public ExternalDNSConfigFluentImpl.AwsNested<A> editOrNewAws() {
    return withNewAwsLike(getAws() != null ? getAws(): new ExternalDNSAWSConfigBuilder().build());
  }
  public ExternalDNSConfigFluentImpl.AwsNested<A> editOrNewAwsLike(ExternalDNSAWSConfig item) {
    return withNewAwsLike(getAws() != null ? getAws(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalDNSGCPConfig getGcp() {
    return this.gcp!=null ?this.gcp.build():null;
  }
  public ExternalDNSGCPConfig buildGcp() {
    return this.gcp!=null ?this.gcp.build():null;
  }
  public A withGcp(ExternalDNSGCPConfig gcp) {
    _visitables.get("gcp").remove(this.gcp);
    if (gcp!=null){ this.gcp= new ExternalDNSGCPConfigBuilder(gcp); _visitables.get("gcp").add(this.gcp);} else { this.gcp = null; _visitables.get("gcp").remove(this.gcp); } return (A) this;
  }
  public Boolean hasGcp() {
    return this.gcp != null;
  }
  public ExternalDNSConfigFluentImpl.GcpNested<A> withNewGcp() {
    return new ExternalDNSConfigFluentImpl.GcpNestedImpl();
  }
  public ExternalDNSConfigFluentImpl.GcpNested<A> withNewGcpLike(ExternalDNSGCPConfig item) {
    return new ExternalDNSConfigFluentImpl.GcpNestedImpl(item);
  }
  public ExternalDNSConfigFluentImpl.GcpNested<A> editGcp() {
    return withNewGcpLike(getGcp());
  }
  public ExternalDNSConfigFluentImpl.GcpNested<A> editOrNewGcp() {
    return withNewGcpLike(getGcp() != null ? getGcp(): new ExternalDNSGCPConfigBuilder().build());
  }
  public ExternalDNSConfigFluentImpl.GcpNested<A> editOrNewGcpLike(ExternalDNSGCPConfig item) {
    return withNewGcpLike(getGcp() != null ? getGcp(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalDNSConfigFluentImpl that = (ExternalDNSConfigFluentImpl) o;
    if (!java.util.Objects.equals(aws, that.aws)) return false;

    if (!java.util.Objects.equals(gcp, that.gcp)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(aws,  gcp,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (aws != null) { sb.append("aws:"); sb.append(aws + ","); }
    if (gcp != null) { sb.append("gcp:"); sb.append(gcp); }
    sb.append("}");
    return sb.toString();
  }
  class AwsNestedImpl<N> extends ExternalDNSAWSConfigFluentImpl<ExternalDNSConfigFluentImpl.AwsNested<N>> implements ExternalDNSConfigFluentImpl.AwsNested<N>,Nested<N>{
    AwsNestedImpl(ExternalDNSAWSConfig item) {
      this.builder = new ExternalDNSAWSConfigBuilder(this, item);
    }
    AwsNestedImpl() {
      this.builder = new ExternalDNSAWSConfigBuilder(this);
    }
    ExternalDNSAWSConfigBuilder builder;
    public N and() {
      return (N) ExternalDNSConfigFluentImpl.this.withAws(builder.build());
    }
    public N endAws() {
      return and();
    }
    
  }
  class GcpNestedImpl<N> extends ExternalDNSGCPConfigFluentImpl<ExternalDNSConfigFluentImpl.GcpNested<N>> implements ExternalDNSConfigFluentImpl.GcpNested<N>,Nested<N>{
    GcpNestedImpl(ExternalDNSGCPConfig item) {
      this.builder = new ExternalDNSGCPConfigBuilder(this, item);
    }
    GcpNestedImpl() {
      this.builder = new ExternalDNSGCPConfigBuilder(this);
    }
    ExternalDNSGCPConfigBuilder builder;
    public N and() {
      return (N) ExternalDNSConfigFluentImpl.this.withGcp(builder.build());
    }
    public N endGcp() {
      return and();
    }
    
  }
  
}
